﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2017 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Encodings.RealVectorEncoding;
using HeuristicLab.Optimization;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Networks.IntegratedOptimization {
  [Item("Variegation Problem", "Represents a problem whose objective is to optimize problem parameters.")]
  [Creatable(CreatableAttribute.Categories.Problems, Priority = 999)]
  [StorableClass]
  public class VariegationProblem : SingleObjectiveBasicProblem<RealVectorEncoding> {
    private bool maximization;
    public override bool Maximization {
      get { return maximization; }
    }

    public void SetMaximization(bool value) {
      maximization = value;
    }

    [StorableConstructor]
    protected VariegationProblem(bool deserializing) : base(deserializing) { }
    protected VariegationProblem(VariegationProblem original, Cloner cloner) : base(original, cloner) { }
    public VariegationProblem() : base() {
      Encoding.Length = 5;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new VariegationProblem(this, cloner);
    }

    public override double Evaluate(Individual individual, IRandom random) { return 0.0; }
  }
}
